@@ -1,7 +1,7 @@
 
 ##  digest -- hash digest functions for R
 ##
-##  Copyright (C) 2003 - 2017  Dirk Eddelbuettel <edd@debian.org>
+##  Copyright (C) 2003 - 2018  Dirk Eddelbuettel <edd@debian.org>
 ##
 ##  This file is part of digest.
 ##
@@ -37,7 +37,7 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
     .errorhandler <- function(txt, obj="", mode="stop") {
         if (mode == "stop") {
             stop(txt, obj, call.=FALSE)
-        } else if (mode == "warn") {
+        } else if (mode == "warn") {	    # #nocov
             warning(txt, obj, call.=FALSE)  # nocov
             return(invisible(NA))           # nocov
         } else {
@@ -79,12 +79,12 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
             ## Was: skip <- if (ascii) 18 else 14
         }
     } else if (!is.character(object) && !inherits(object,"raw")) {
-        return(.errorhandler(paste("Argument object must be of type character",	# nocov
-                                   "or raw vector if serialize is FALSE"), mode=errormode)) # nocov
+        return(.errorhandler(paste("Argument object must be of type character",		    # #nocov
+                                   "or raw vector if serialize is FALSE"), mode=errormode)) # #nocov
     }
     if (file && !is.character(object))
-        return(.errorhandler("file=TRUE can only be used with a character object",
-                             mode=errormode))
+        return(.errorhandler("file=TRUE can only be used with a character object",          # #nocov
+                             mode=errormode))                                               # #nocov
     ## HB 14 Mar 2007:  null op, only turned to char if alreadt char
     ##if (!inherits(object,"raw"))
     ##  object <- as.character(object)
@@ -123,5 +123,12 @@ digest <- function(object, algo=c("md5", "sha1", "crc32", "sha256", "sha512",
                  as.integer(skip),
                  as.integer(raw),
                  as.integer(seed))
+
+    ## crc32 output was not guaranteed to be eight chars long, which we corrected
+    ## this allows to get the old behaviour back for compatibility
+    if ((algoint == 3 || algoint == 103) && .getCRC32PreferOldOutput()) {
+        val <- sub("^0+", "", val)
+    }
+
     return(val)
 }
